Config
------

.. autoclass:: sokoenginepy.game.Config
    :members:
    :undoc-members:

Functions
---------

.. autofunction:: sokoenginepy.game.index_1d
.. autofunction:: sokoenginepy.game.X
.. autofunction:: sokoenginepy.game.Y
.. autofunction:: sokoenginepy.game.ROW
.. autofunction:: sokoenginepy.game.COLUMN
.. autofunction:: sokoenginepy.game.is_on_board_2d
.. autofunction:: sokoenginepy.game.is_on_board_1d
